# OptHub CLI Client

This package provides a commandline interface to operate OptHub.


## Requirements

Python 2.7 or 3.5+


## Installation

```
$ pip install opthub-client-cli
```


## Usage

```
$ opt --help
```


## Author

Naoki Hamada (hmkz@s101.xrea.com)


## License

[MIT](LICENSE)
